@@ -24,9 +24,8 @@
 
 #include <kdeversion.h>
 
-#if KDE_IS_VERSION(4,1,85)
 #include <kfilterproxysearchline.h>
-#endif
+#include <klineedit.h>
 
 using namespace Akonadi;
 
@@ -43,21 +42,22 @@ AgentTypeDialog::AgentTypeDialog( QWidget *parent )
 {
   setButtons( Ok | Cancel );
   QVBoxLayout *layout = new QVBoxLayout( mainWidget() );
+  layout->setMargin(0);
 
   d->Widget = new Akonadi::AgentTypeWidget( mainWidget() );
-  connect( d->Widget, SIGNAL( activated() ), this, SLOT( accept() ) );
+  connect( d->Widget, SIGNAL(activated()), this, SLOT(accept()) );
 
-#if KDE_IS_VERSION(4,1,85)
   KFilterProxySearchLine* searchLine = new KFilterProxySearchLine( mainWidget() );
   layout->addWidget( searchLine );
   searchLine->setProxy( d->Widget->agentFilterProxyModel() );
-#endif
 
   layout->addWidget( d->Widget );
 
-  connect( this, SIGNAL( okClicked() ), this, SLOT( accept() ) );
+  connect( this, SIGNAL(okClicked()), this, SLOT(accept()) );
 
   resize( 460, 320 );
+
+  searchLine->lineEdit()->setFocus();
 }
 
 AgentTypeDialog::~AgentTypeDialog()
