@@ -55,6 +55,16 @@ StandardContactFormatter::~StandardContactFormatter()
   delete d;
 }
 
+static int contactAge( const QDate &date )
+{
+  QDate now = QDate::currentDate();
+  int age = now.year() - date.year();
+  if ( date > now.addYears( -age ) ) {
+    age--;
+  }
+  return age;
+}
+
 QString StandardContactFormatter::toHtml( HtmlForm form ) const
 {
   KABC::Addressee rawContact;
@@ -82,7 +92,7 @@ QString StandardContactFormatter::toHtml( HtmlForm form ) const
 
   // Birthday
   const QDate date = rawContact.birthday().date();
-  const int years = (date.daysTo( QDate::currentDate() ) / 365);
+  const int years = contactAge( date );
 
   if ( date.isValid() )
     dynamicPart += rowFmtStr
@@ -200,7 +210,7 @@ QString StandardContactFormatter::toHtml( HtmlForm form ) const
         QString value = custom.mid( pos + 1 );
 
         // convert anniversary correctly
-        if ( key == QLatin1String( "Anniversary" ) ) {
+        if ( key == QLatin1String( "Anniversary" ) || key == QLatin1String( "ANNIVERSARY" ) ) {
           const QDateTime dateTime = QDateTime::fromString( value, Qt::ISODate );
           value = KGlobal::locale()->formatDate( dateTime.date() );
         }
