@@ -164,8 +164,8 @@ ConfigPage::ConfigPage( QWidget *parent )
   d->mListView->setHeaderItem( new QTreeWidgetItem( headerLabels ) );
 
   groupBoxLayout->addWidget( d->mListView, 1, 0 );
-  connect( d->mListView, SIGNAL( itemDoubleClicked( QTreeWidgetItem *, int ) ),
-           this, SLOT( slotEdit() ) );
+  connect( d->mListView, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
+           this, SLOT(slotEdit()) );
 
   KDialogButtonBox *buttonBox = new KDialogButtonBox( groupBox, Qt::Vertical );
   d->mAddButton = buttonBox->addButton( i18n( "&Add..." ),
@@ -192,12 +192,12 @@ ConfigPage::ConfigPage( QWidget *parent )
 
   mainLayout->addWidget( groupBox );
 
-  connect( d->mFamilyCombo, SIGNAL( activated( int ) ),
-           SLOT( slotFamilyChanged( int ) ) );
-  connect( d->mListView, SIGNAL( itemSelectionChanged() ),
-           SLOT( slotSelectionChanged() ) );
-  connect( d->mListView, SIGNAL( itemClicked( QTreeWidgetItem *, int ) ),
-           SLOT( slotItemClicked( QTreeWidgetItem * ) ) );
+  connect( d->mFamilyCombo, SIGNAL(activated(int)),
+           SLOT(slotFamilyChanged(int)) );
+  connect( d->mListView, SIGNAL(itemSelectionChanged()),
+           SLOT(slotSelectionChanged()) );
+  connect( d->mListView, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
+           SLOT(slotItemClicked(QTreeWidgetItem*)) );
 
   d->mLastItem = 0;
 
@@ -250,7 +250,9 @@ void ConfigPage::load()
     if ( !family.isEmpty() ) {
       compatFamilyNames.removeAll( family );
       d->mFamilyMap.append( family );
+      kDebug() << "Loading manager for family " << family;
       d->loadManager( family, this );
+      kDebug() << "Manager for family " << family << " loaded.";
     }
   }
 
@@ -380,7 +382,7 @@ void ConfigPage::slotAdd()
 
   ConfigDialog dlg( this, d->mFamily, resource );
 
-  if ( dlg.exec() ) {
+  if ( dlg.exec() ) { //krazy:exclude=crashy
     d->mCurrentManager->add( resource );
 
     ConfigViewItem *item = new ConfigViewItem( d->mListView, resource );
@@ -458,7 +460,7 @@ void ConfigPage::slotEdit()
 
   ConfigDialog dlg( this, d->mFamily, resource );
 
-  if ( dlg.exec() ) {
+  if ( dlg.exec() ) { //krazy:exclude=crashy
     configItem->setText( 0, resource->resourceName() );
     configItem->setText( 1, resource->type() );
 
